@@ -768,7 +768,15 @@ void ScTable::CopyToTable(SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
         return;
 
     if (pDBDataNoName)
-        pDestTab->SetAnonymousDBData(new ScDBData(*pDBDataNoName));
+    {
+        ScDBData* pNewDBData = new ScDBData(*pDBDataNoName);
+        SCCOL aCol1, aCol2;
+        SCROW aRow1, aRow2;
+        SCTAB aTab;
+        pNewDBData->GetArea(aTab, aCol1, aRow1, aCol2, aRow2);
+        pNewDBData->MoveTo(pDestTab->nTab, aCol1, aRow1, aCol2, aRow2);
+        pDestTab->SetAnonymousDBData(pNewDBData);
+    }
     //	Charts muessen beim Ein-/Ausblenden angepasst werden
     ScChartListenerCollection* pCharts = pDestTab->pDocument->GetChartListenerCollection();
 
@@ -1381,7 +1389,7 @@ bool ScTable::HasAttribSelection( const ScMarkData& rMark, sal_uInt16 nMask ) co
 
 bool ScTable::ExtendMerge( SCCOL nStartCol, SCROW nStartRow,
                            SCCOL& rEndCol, SCROW& rEndRow,
-                           sal_Bool bRefresh, sal_Bool bAttrs )
+                           sal_Bool bRefresh )
 {
     if (!(ValidCol(nStartCol) && ValidCol(rEndCol)))
     {
@@ -1392,7 +1400,7 @@ bool ScTable::ExtendMerge( SCCOL nStartCol, SCROW nStartRow,
     SCCOL nOldEndX = rEndCol;
     SCROW nOldEndY = rEndRow;
     for (SCCOL i=nStartCol; i<=nOldEndX; i++)
-        bFound |= aCol[i].ExtendMerge( i, nStartRow, nOldEndY, rEndCol, rEndRow, bRefresh, bAttrs );
+        bFound |= aCol[i].ExtendMerge( i, nStartRow, nOldEndY, rEndCol, rEndRow, bRefresh );
     return bFound;
 }
 
@@ -3046,6 +3054,10 @@ void ScTable::SetRangeName(ScRangeName* pNew)
 {
     delete mpRangeName;
     mpRangeName = pNew;
+
+    //fdo#39792: mark stream as invalid, otherwise new ScRangeName will not be written to file
+    if (IsStreamValid())
+        SetStreamValid(false);
 }
 
 ScRangeName* ScTable::GetRangeName() const
