@@ -244,6 +244,7 @@ private:
 ScMatrixImpl::ScMatrixImpl(SCSIZE nC, SCSIZE nR, ScMatrix::DensityType eType) :
     maMat(nR, nC, toMddsDensityType(eType)),
     meType(eType),
+    pErrorInterpreter(NULL),
     mbCloneIfConst(true)
 {
 }
@@ -463,12 +464,15 @@ const String& ScMatrixImpl::GetString(SCSIZE nC, SCSIZE nR) const
 {
     if (ValidColRowOrReplicated( nC, nR ))
     {
-        if (maMat.get_type(nR, nC) == ::mdds::element_string)
-            return *maMat.get_string(nR, nC);
-        else
+        switch (maMat.get_type(nR, nC))
         {
-            SetErrorAtInterpreter( GetError(nC, nR));
-            DBG_ERRORFILE("ScMatrixImpl::GetString: access error, no string");
+            case ::mdds::element_string:
+                return *maMat.get_string(nR, nC);
+            case ::mdds::element_empty:
+                return ScGlobal::GetEmptyString();
+            default:
+                SetErrorAtInterpreter( GetError(nC, nR));
+                OSL_FAIL("ScMatrixImpl::GetString: access error, no string");
         }
     }
     else
@@ -589,8 +593,10 @@ bool ScMatrixImpl::IsEmpty( SCSIZE nC, SCSIZE nR ) const
 bool ScMatrixImpl::IsEmptyPath( SCSIZE nC, SCSIZE nR ) const
 {
     // 'Empty path' is empty plus non-zero flag.
-    ValidColRowReplicated( nC, nR );
-    return maMat.get_type(nR, nC) == ::mdds::element_empty && maMat.get_flag(nR, nC) != 0;
+    if (ValidColRowOrReplicated( nC, nR ))
+        return maMat.get_type(nR, nC) == ::mdds::element_empty && maMat.get_flag(nR, nC) != 0;
+    else
+        return true;
 }
 
 bool ScMatrixImpl::IsValue( SCSIZE nIndex ) const
@@ -730,7 +736,7 @@ bool EvalMatrix(const MatrixImplType& rMat)
         for (size_t j = 0; j < nCols; ++j)
         {
             matrix_element_t eType = rMat.get_type(i, j);
-            if (eType != mdds::element_numeric && eType == mdds::element_boolean)
+            if (eType != mdds::element_numeric && eType != mdds::element_boolean)
                 // assuming a CompareMat this is an error
                 return CreateDoubleError(errIllegalArgument);
 
