@@ -2,7 +2,7 @@
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
- * 
+ *
  * Copyright 2000, 2010 Oracle and/or its affiliates.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -39,12 +39,13 @@
 #include "cell.hxx"
 #include "xcl97rec.hxx"
 
-#include <oox/core/tokens.hxx>
+#include <oox/token/tokens.hxx>
 #include <rtl/strbuf.hxx>
 
 using ::rtl::OUString;
 using ::rtl::OString;
 using ::rtl::OStringBuffer;
+using namespace oox;
 
 static OString lcl_GuidToOString( sal_uInt8 aGuid[ 16 ] )
 {
@@ -96,7 +97,7 @@ void lcl_WriteFixedString( XclExpStream& rStrm, const XclExpString& rString, sal
 
 inline void lcl_GenerateGUID( sal_uInt8* pGUID, sal_Bool& rValidGUID )
 {
-    rtl_createUuid( pGUID, rValidGUID ? pGUID : NULL, sal_False );
+    rtl_createUuid( pGUID, rValidGUID ? pGUID : NULL, false );
     rValidGUID = sal_True;
 }
 
@@ -133,7 +134,7 @@ void XclExpUserBView::SaveCont( XclExpStream& rStrm )
         rStrm << sUsername;
 }
 
-UINT16 XclExpUserBView::GetNum() const
+sal_uInt16 XclExpUserBView::GetNum() const
 {
     return 0x01A9;
 }
@@ -148,9 +149,9 @@ sal_Size XclExpUserBView::GetLen() const
 XclExpUserBViewList::XclExpUserBViewList( const ScChangeTrack& rChangeTrack )
 {
     sal_uInt8 aGUID[ 16 ];
-    sal_Bool bValidGUID = sal_False;
+    sal_Bool bValidGUID = false;
     const ScStrCollection& rStrColl = rChangeTrack.GetUserCollection();
-    for( USHORT nIndex = 0; nIndex < rStrColl.GetCount(); nIndex++ )
+    for( sal_uInt16 nIndex = 0; nIndex < rStrColl.GetCount(); nIndex++ )
     {
         const StrData* pStrData = (const StrData*) rStrColl.At( nIndex );
         lcl_GenerateGUID( aGUID, bValidGUID );
@@ -197,7 +198,7 @@ void XclExpUsersViewBegin::SaveCont( XclExpStream& rStrm )
             << (sal_Int16)	-1;
 }
 
-UINT16 XclExpUsersViewBegin::GetNum() const
+sal_uInt16 XclExpUsersViewBegin::GetNum() const
 {
     return 0x01AA;
 }
@@ -214,7 +215,7 @@ void XclExpUsersViewEnd::SaveCont( XclExpStream& rStrm )
     rStrm << (sal_uInt16) 0x0001;
 }
 
-UINT16 XclExpUsersViewEnd::GetNum() const
+sal_uInt16 XclExpUsersViewEnd::GetNum() const
 {
     return 0x01AB;
 }
@@ -231,7 +232,7 @@ void XclExpChTr0x0191::SaveCont( XclExpStream& rStrm )
     rStrm << (sal_uInt16) 0x0000;
 }
 
-UINT16 XclExpChTr0x0191::GetNum() const
+sal_uInt16 XclExpChTr0x0191::GetNum() const
 {
     return 0x0191;
 }
@@ -249,7 +250,7 @@ void XclExpChTr0x0198::SaveCont( XclExpStream& rStrm )
             << (sal_uInt16) 0x0000;
 }
 
-UINT16 XclExpChTr0x0198::GetNum() const
+sal_uInt16 XclExpChTr0x0198::GetNum() const
 {
     return 0x0198;
 }
@@ -267,7 +268,7 @@ void XclExpChTr0x0192::SaveCont( XclExpStream& rStrm )
     rStrm.WriteZeroBytes( 510 );
 }
 
-UINT16 XclExpChTr0x0192::GetNum() const
+sal_uInt16 XclExpChTr0x0192::GetNum() const
 {
     return 0x0192;
 }
@@ -284,7 +285,7 @@ void XclExpChTr0x0197::SaveCont( XclExpStream& rStrm )
     rStrm << (sal_uInt16) 0x0000;
 }
 
-UINT16 XclExpChTr0x0197::GetNum() const
+sal_uInt16 XclExpChTr0x0197::GetNum() const
 {
     return 0x0197;
 }
@@ -300,7 +301,7 @@ XclExpChTrEmpty::~XclExpChTrEmpty()
 {
 }
 
-UINT16 XclExpChTrEmpty::GetNum() const
+sal_uInt16 XclExpChTrEmpty::GetNum() const
 {
     return nRecNum;
 }
@@ -321,7 +322,7 @@ void XclExpChTr0x0195::SaveCont( XclExpStream& rStrm )
     rStrm.WriteZeroBytes( 162 );
 }
 
-UINT16 XclExpChTr0x0195::GetNum() const
+sal_uInt16 XclExpChTr0x0195::GetNum() const
 {
     return 0x0195;
 }
@@ -345,7 +346,7 @@ void XclExpChTr0x0194::SaveCont( XclExpStream& rStrm )
     lcl_WriteFixedString( rStrm, sUsername, 147 );
 }
 
-UINT16 XclExpChTr0x0194::GetNum() const
+sal_uInt16 XclExpChTr0x0194::GetNum() const
 {
     return 0x0194;
 }
@@ -374,7 +375,7 @@ void XclExpChTrHeader::SaveCont( XclExpStream& rStrm )
             << (sal_uInt16) 0x001E;
 }
 
-UINT16 XclExpChTrHeader::GetNum() const
+sal_uInt16 XclExpChTrHeader::GetNum() const
 {
     return 0x0196;
 }
@@ -424,7 +425,7 @@ void XclExpChTrInfo::SaveCont( XclExpStream& rStrm )
             << (sal_uInt16)	0x0002;
 }
 
-UINT16 XclExpChTrInfo::GetNum() const
+sal_uInt16 XclExpChTrInfo::GetNum() const
 {
     return 0x0138;
 }
@@ -575,7 +576,7 @@ void XclExpChTrTabId::SaveCont( XclExpStream& rStrm )
             rStrm << nIndex;
 }
 
-UINT16 XclExpChTrTabId::GetNum() const
+sal_uInt16 XclExpChTrTabId::GetNum() const
 {
     return 0x013D;
 }
@@ -640,7 +641,7 @@ XclExpChTrAction::XclExpChTrAction(
     rIdBuffer( rTabIdBuffer ),
     nLength( 0 ),
     nOpCode( nNewOpCode ),
-    bForceInfo( sal_False )
+    bForceInfo( false )
 {
     aDateTime.SetSec( 0 );
     aDateTime.Set100Sec( 0 );
@@ -741,7 +742,7 @@ void XclExpChTrData::Clear()
 
 void XclExpChTrData::WriteFormula( XclExpStream& rStrm, const XclExpChTrTabIdBuffer& rTabIdBuffer )
 {
-    DBG_ASSERT( mxTokArr.is() && !mxTokArr->Empty(), "XclExpChTrData::Write - no formula" );
+    DBG_ASSERT( mxTokArr && !mxTokArr->Empty(), "XclExpChTrData::Write - no formula" );
     rStrm << *mxTokArr;
 
     for( XclExpRefLog::const_iterator aIt = maRefLog.begin(), aEnd = maRefLog.end(); aIt != aEnd; ++aIt )
@@ -930,7 +931,7 @@ void XclExpChTrCellContent::SaveActionData( XclExpStream& rStrm ) const
         pNewData->Write( rStrm, rIdBuffer );
 }
 
-UINT16 XclExpChTrCellContent::GetNum() const
+sal_uInt16 XclExpChTrCellContent::GetNum() const
 {
     return 0x013B;
 }
@@ -949,24 +950,26 @@ static const char* lcl_GetType( XclExpChTrData* pData )
 {
     switch( pData->nType )
     {
-        case EXC_CHTR_TYPE_RK:
-        case EXC_CHTR_TYPE_DOUBLE:
-            return "n";
-            break;
-        case EXC_CHTR_TYPE_FORMULA:
-            {
-                ScFormulaCell* pFormulaCell = const_cast< ScFormulaCell* >( pData->mpFormulaCell );
-                const char* sType;
-                OUString sValue;
-                XclXmlUtils::GetFormulaTypeAndValue( *pFormulaCell, sType, sValue );
-                return sType;
-            }
-            break;
-        case EXC_CHTR_TYPE_STRING:
-            return "inlineStr";
-        default:
-            return "*unknown*";
+    case EXC_CHTR_TYPE_RK:
+    case EXC_CHTR_TYPE_DOUBLE:
+        return "n";
+        break;
+    case EXC_CHTR_TYPE_FORMULA:
+        {
+            ScFormulaCell* pFormulaCell = const_cast< ScFormulaCell* >( pData->mpFormulaCell );
+            const char* sType;
+            OUString sValue;
+            XclXmlUtils::GetFormulaTypeAndValue( *pFormulaCell, sType, sValue );
+            return sType;
+        }
+        break;
+    case EXC_CHTR_TYPE_STRING:
+        return "inlineStr";
+        break;
+    default:
+        break;
     }
+    return "*unknown*";
 }
 
 static void lcl_WriteCell( XclExpXmlStream& rStrm, sal_Int32 nElement, const ScAddress& rPosition, XclExpChTrData* pData )
@@ -1000,7 +1003,7 @@ static void lcl_WriteCell( XclExpXmlStream& rStrm, sal_Int32 nElement, const ScA
             break;
         case EXC_CHTR_TYPE_STRING:
             pStream->startElement( XML_is, FSEND );
-            if( pData->mpFormattedString.is() )
+            if( pData->mpFormattedString )
                 pData->mpFormattedString->WriteXml( rStrm );
             else
                 pData->pString->WriteXml( rStrm );
@@ -1062,7 +1065,7 @@ XclExpChTrInsert::XclExpChTrInsert(
         case SC_CAT_DELETE_COLS:	nOpCode = EXC_CHTR_OP_DELCOL;	break;
         case SC_CAT_DELETE_ROWS:	nOpCode = EXC_CHTR_OP_DELROW;	break;
         default:
-            DBG_ERROR( "XclExpChTrInsert::XclExpChTrInsert - unknown action" );
+            OSL_FAIL( "XclExpChTrInsert::XclExpChTrInsert - unknown action" );
     }
 
     if( nOpCode & EXC_CHTR_OP_COLFLAG )
@@ -1107,7 +1110,7 @@ void XclExpChTrInsert::CompleteSaveAction( XclExpStream& rStrm ) const
         XclExpChTrEmpty( 0x0151 ).Save( rStrm );
 }
 
-UINT16 XclExpChTrInsert::GetNum() const
+sal_uInt16 XclExpChTrInsert::GetNum() const
 {
     return 0x0137;
 }
@@ -1179,7 +1182,7 @@ void XclExpChTrInsertTab::SaveActionData( XclExpStream& rStrm ) const
     rStrm.WriteZeroBytes( 133 );
 }
 
-UINT16 XclExpChTrInsertTab::GetNum() const
+sal_uInt16 XclExpChTrInsertTab::GetNum() const
 {
     return 0x014D;
 }
@@ -1248,7 +1251,7 @@ void XclExpChTrMoveRange::CompleteSaveAction( XclExpStream& rStrm ) const
     XclExpChTrEmpty( 0x014F ).Save( rStrm );
 }
 
-UINT16 XclExpChTrMoveRange::GetNum() const
+sal_uInt16 XclExpChTrMoveRange::GetNum() const
 {
     return 0x0140;
 }
@@ -1302,7 +1305,7 @@ void XclExpChTr0x014A::SaveActionData( XclExpStream& rStrm ) const
     Write2DRange( rStrm, aRange );
 }
 
-UINT16 XclExpChTr0x014A::GetNum() const
+sal_uInt16 XclExpChTr0x014A::GetNum() const
 {
     return 0x014A;
 }
@@ -1377,7 +1380,7 @@ class ExcXmlRecord : public ExcRecord
 {
 public:
     virtual sal_Size    GetLen() const;
-    virtual UINT16      GetNum() const;
+    virtual sal_uInt16  GetNum() const;
     virtual void        Save( XclExpStream& rStrm );
     virtual void        SaveXml( XclExpXmlStream& rStrm ) = 0;
 };
@@ -1387,7 +1390,7 @@ sal_Size ExcXmlRecord::GetLen() const
     return 0;
 }
 
-UINT16 ExcXmlRecord::GetNum() const
+sal_uInt16 ExcXmlRecord::GetNum() const
 {
     return 0;
 }
@@ -1467,7 +1470,7 @@ XclExpChangeTrack::XclExpChangeTrack( const XclExpRoot& rRoot ) :
     pTempDoc( NULL ),
     nNewAction( 1 ),
     pHeader( NULL ),
-    bValidGUID( sal_False )
+    bValidGUID( false )
 {
     DBG_ASSERT( GetOldRoot().pTabId, "XclExpChangeTrack::XclExpChangeTrack - root data incomplete" );
     if( !GetOldRoot().pTabId )
@@ -1582,7 +1585,7 @@ ScChangeTrack* XclExpChangeTrack::CreateTempChangeTrack()
     DBG_ASSERT( nOrigCount == pTempDoc->GetTableCount(),
         "XclExpChangeTrack::CreateTempChangeTrack - table count mismatch" );
     if( nOrigCount != pTempDoc->GetTableCount() )
-        return sal_False;
+        return false;
 
     return pOrigChangeTrack->Clone(pTempDoc);
 }
@@ -1624,7 +1627,7 @@ void XclExpChangeTrack::PushActionRecord( const ScChangeAction& rAction )
 
 sal_Bool XclExpChangeTrack::WriteUserNamesStream()
 {
-    sal_Bool bRet = sal_False;
+    sal_Bool bRet = false;
     SotStorageStreamRef xSvStrm = OpenStream( EXC_STREAM_USERNAMES );
     DBG_ASSERT( xSvStrm.Is(), "XclExpChangeTrack::WriteUserNamesStream - no stream" );
     if( xSvStrm.Is() )
@@ -1661,8 +1664,8 @@ void XclExpChangeTrack::Write()
 static void lcl_WriteUserNamesXml( XclExpXmlStream& rWorkbookStrm )
 {
     sax_fastparser::FSHelperPtr pUserNames = rWorkbookStrm.CreateOutputStream(
-            OUString::createFromAscii( "xl/revisions/userNames.xml" ),
-            OUString::createFromAscii( "revisions/userNames.xml" ),
+            OUString(RTL_CONSTASCII_USTRINGPARAM( "xl/revisions/userNames.xml" )),
+            OUString(RTL_CONSTASCII_USTRINGPARAM( "revisions/userNames.xml" )),
             rWorkbookStrm.GetCurrentStream()->getOutputStream(),
             "application/vnd.openxmlformats-officedocument.spreadsheetml.userNames+xml",
             "http://schemas.openxmlformats.org/officeDocument/2006/relationships/usernames" );
@@ -1685,8 +1688,8 @@ void XclExpChangeTrack::WriteXml( XclExpXmlStream& rWorkbookStrm )
     lcl_WriteUserNamesXml( rWorkbookStrm );
 
     sax_fastparser::FSHelperPtr pRevisionHeaders = rWorkbookStrm.CreateOutputStream(
-            OUString::createFromAscii( "xl/revisions/revisionHeaders.xml" ),
-            OUString::createFromAscii( "revisions/revisionHeaders.xml" ),
+            OUString(RTL_CONSTASCII_USTRINGPARAM( "xl/revisions/revisionHeaders.xml" )),
+            OUString(RTL_CONSTASCII_USTRINGPARAM( "revisions/revisionHeaders.xml" )),
             rWorkbookStrm.GetCurrentStream()->getOutputStream(),
             "application/vnd.openxmlformats-officedocument.spreadsheetml.revisionHeaders+xml",
             "http://schemas.openxmlformats.org/officeDocument/2006/relationships/revisionHeaders" );
